@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2010-2011 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2022 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2023 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,7 +47,11 @@
 #include <freerdp/gdi/region.h>
 #include <freerdp/client/cliprdr.h>
 #include <freerdp/client/disp.h>
+#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
+#elif defined(GDK_WINDOWING_WAYLAND)
+#include <gdk/gdkwayland.h>
+#endif
 
 #include <winpr/clipboard.h>
 
@@ -155,18 +159,22 @@ struct rf_pointer {
 };
 typedef struct rf_pointer rfPointer;
 
+#ifdef RF_BITMAP
 struct rf_bitmap {
 	rdpBitmap		bitmap;
 	Pixmap			pixmap;
 	cairo_surface_t *	surface;
 };
 typedef struct rf_bitmap rfBitmap;
+#endif
 
+#ifdef RF_GLYPH
 struct rf_glyph {
 	rdpGlyph	glyph;
 	Pixmap		pixmap;
 };
 typedef struct rf_glyph rfGlyph;
+#endif
 
 typedef enum {
 	REMMINA_RDP_EVENT_TYPE_SCANCODE,
