@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2009-2011 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2022 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2023 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -197,9 +197,13 @@ void remmina_file_set_statefile(RemminaFile *remminafile)
 
 	gchar *basename = g_path_get_basename(remminafile->filename);
 	gchar *cachedir = g_build_path("/", g_get_user_cache_dir(), "remmina", NULL);
-	GString *fname = g_string_new(g_strdup(basename));
+	GString *fname = g_string_new(basename);
 
 	remminafile->statefile = g_strdup_printf("%s/%s.state", cachedir, fname->str);
+
+	g_free(cachedir);
+	g_string_free(fname, TRUE);
+	g_free(basename);
 }
 
 const gchar *
@@ -214,13 +218,13 @@ remmina_file_copy(const gchar *filename)
 {
 	TRACE_CALL(__func__);
 	RemminaFile *remminafile;
+	gchar *buf;
 
 	remminafile = remmina_file_load(filename);
-	remmina_file_set_string(remminafile,
-				"name",
-				g_strdup_printf(
-					"COPY %s",
-					remmina_file_get_string(remminafile, "name")));
+	buf = g_strdup_printf( "COPY %s",
+			remmina_file_get_string(remminafile, "name"));
+	remmina_file_set_string(remminafile, "name", buf);
+	g_free(buf);
 
 	if (remminafile)
 		remmina_file_generate_filename(remminafile);
@@ -387,7 +391,7 @@ remmina_file_load(const gchar *filename)
 	}
 
 	secret_plugin = remmina_plugin_manager_get_secret_plugin();
-	secret_service_available = secret_plugin && secret_plugin->is_service_available();
+	secret_service_available = secret_plugin && secret_plugin->is_service_available(secret_plugin);
 
 	remminafile->filename = g_strdup(filename);
 	gsize nkeys = 0;
@@ -421,13 +425,16 @@ remmina_file_load(const gchar *filename)
 			}
 #endif
 			if ((g_strcmp0(s, ".") == 0) && (secret_service_available)) {
-				gchar *sec = secret_plugin->get_password(remminafile, key);
+				gchar *sec = secret_plugin->get_password(secret_plugin, remminafile, key);
 				remmina_file_set_string(remminafile, key, sec);
 				/* Annotate in spsettings that this value comes from secret_plugin */
 				g_hash_table_insert(remminafile->spsettings, g_strdup(key), NULL);
 				g_free(sec);
 			} else {
-				remmina_file_set_string_ref(remminafile, key, remmina_crypt_decrypt(s));
+				gchar *decrypted;
+				decrypted = remmina_crypt_decrypt(s);
+				remmina_file_set_string(remminafile, key, decrypted);
+				g_free(decrypted);
 			}
 			g_free(s), s = NULL;
 		} else {
@@ -435,16 +442,19 @@ remmina_file_load(const gchar *filename)
 			if (strcmp(key, "resolution") == 0) {
 				gchar *resolution_str = g_key_file_get_string(gkeyfile, KEYFILE_GROUP_REMMINA, key, NULL);
 				if (remmina_public_split_resolution_string(resolution_str, &w, &h)) {
-					remmina_file_set_string_ref(remminafile, "resolution_width", g_strdup_printf("%i", w));
-					remmina_file_set_string_ref(remminafile, "resolution_height", g_strdup_printf("%i", h));
+					gchar *buf;
+					buf = g_strdup_printf("%i", w); remmina_file_set_string(remminafile, "resolution_width", buf); g_free(buf);
+					buf = g_strdup_printf("%i", h); remmina_file_set_string(remminafile, "resolution_height", buf); g_free(buf);
 				} else {
-					remmina_file_set_string_ref(remminafile, "resolution_width", NULL);
-					remmina_file_set_string_ref(remminafile, "resolution_height", NULL);
+					remmina_file_set_string(remminafile, "resolution_width", NULL);
+					remmina_file_set_string(remminafile, "resolution_height", NULL);
 				}
 				g_free(resolution_str);
 			} else {
-				remmina_file_set_string_ref(remminafile, key,
-						g_key_file_get_string(gkeyfile, KEYFILE_GROUP_REMMINA, key, NULL));
+				gchar *value;
+				value = g_key_file_get_string(gkeyfile, KEYFILE_GROUP_REMMINA, key, NULL);
+				remmina_file_set_string(remminafile, key, value);
+				g_free(value);
 			}
 		}
 	}
@@ -459,12 +469,23 @@ remmina_file_load(const gchar *filename)
 void remmina_file_set_string(RemminaFile *remminafile, const gchar *setting, const gchar *value)
 {
 	TRACE_CALL(__func__);
-	remmina_file_set_string_ref(remminafile, setting, g_strdup(value));
-}
 
-void remmina_file_set_string_ref(RemminaFile *remminafile, const gchar *setting, gchar *value)
-{
-	TRACE_CALL(__func__);
+	/* Note: setting and value are copied on the heap, so it is responsibility of the caller
+	 * to deallocate them when returning from remmina_file_set_string() if needed */
+
+	if (!remmina_masterthread_exec_is_main_thread()) {
+		/* Allow the execution of this function from a non main thread
+		 * (plugins needs it to have user credentials)*/
+		RemminaMTExecData *d;
+		d = (RemminaMTExecData *)g_malloc(sizeof(RemminaMTExecData));
+		d->func = FUNC_FILE_SET_STRING;
+		d->p.file_set_string.remminafile = remminafile;
+		d->p.file_set_string.setting = setting;
+		d->p.file_set_string.value = value;
+		remmina_masterthread_exec_and_wait(d);
+		g_free(d);
+		return;
+	}
 
 	if (value) {
 		/* We refuse to accept to set the "resolution" field */
@@ -475,7 +496,7 @@ void remmina_file_set_string_ref(RemminaFile *remminafile, const gchar *setting,
 			remmina_main_show_warning_dialog(message);
 			return;
 		}
-		g_hash_table_insert(remminafile->settings, g_strdup(setting), value);
+		g_hash_table_insert(remminafile->settings, g_strdup(setting), g_strdup(value));
 	} else {
 		g_hash_table_insert(remminafile->settings, g_strdup(setting), g_strdup(""));
 	}
@@ -741,7 +762,7 @@ void remmina_file_save(RemminaFile *remminafile)
 	}
 
 	secret_plugin = remmina_plugin_manager_get_secret_plugin();
-	secret_service_available = secret_plugin && secret_plugin->is_service_available();
+	secret_service_available = secret_plugin && secret_plugin->is_service_available(secret_plugin);
 
 	g_hash_table_iter_init(&iter, remminafile->settings);
 	while (g_hash_table_iter_next(&iter, (gpointer *)&key, (gpointer *)&value)) {
@@ -751,11 +772,11 @@ void remmina_file_save(RemminaFile *remminafile)
 					REMMINA_DEBUG("We have a secret and disablepasswordstoring=0");
 					if (value && value[0]) {
 						if (g_strcmp0(value, ".") != 0)
-							secret_plugin->store_password(remminafile, key, value);
+							secret_plugin->store_password(secret_plugin, remminafile, key, value);
 						g_key_file_set_string(gkeyfile, KEYFILE_GROUP_REMMINA, key, ".");
 					} else {
 						g_key_file_set_string(gkeyfile, KEYFILE_GROUP_REMMINA, key, "");
-						secret_plugin->delete_password(remminafile, key);
+						secret_plugin->delete_password(secret_plugin, remminafile, key);
 					}
 				} else {
 					REMMINA_DEBUG("We have a password and disablepasswordstoring=0");
@@ -771,7 +792,7 @@ void remmina_file_save(RemminaFile *remminafile)
 					if (value && value[0]) {
 						if (g_strcmp0(value, ".") != 0) {
 							REMMINA_DEBUG("Deleting the secret in the keyring as disablepasswordstoring=1");
-							secret_plugin->delete_password(remminafile, key);
+							secret_plugin->delete_password(secret_plugin, remminafile, key);
 							g_key_file_set_string(gkeyfile, KEYFILE_GROUP_REMMINA, key, ".");
 						}
 					}
@@ -831,7 +852,7 @@ void remmina_file_store_secret_plugin_password(RemminaFile *remminafile, const g
 
 	if (g_hash_table_lookup_extended(remminafile->spsettings, g_strdup(key), NULL, NULL)) {
 		plugin = remmina_plugin_manager_get_secret_plugin();
-		plugin->store_password(remminafile, key, value);
+		plugin->store_password(plugin, remminafile, key, value);
 	} else {
 		remmina_file_set_string(remminafile, key, value);
 		remmina_file_save(remminafile);
@@ -1015,6 +1036,7 @@ remmina_file_get_datetime(RemminaFile *remminafile)
 	struct timeval tv;
 	struct tm *ptm;
 	char time_string[256];
+	gchar *tmps;
 
 	guint64 mtime;
 
@@ -1041,10 +1063,14 @@ remmina_file_get_datetime(RemminaFile *remminafile)
 		if (last_success) {
 			//REMMINA_DEBUG ("Last success is %s", last_success);
 			GDateTime *dt;
-			dt = g_date_time_new_from_iso8601(g_strconcat(last_success, "T00:00:00Z", NULL), NULL);
+			tmps = g_strconcat(last_success, "T00:00:00Z", NULL);
+			dt = g_date_time_new_from_iso8601(tmps, NULL);
+			g_free(tmps);
 			if (dt) {
 				//REMMINA_DEBUG("Converting last_success");
-				mtime = g_ascii_strtoull(g_date_time_format(dt, "%s"), NULL, 10);
+				tmps = g_date_time_format(dt, "%s");
+				mtime = g_ascii_strtoull(tmps, NULL, 10);
+				g_free(tmps);
 				g_date_time_unref(dt);
 			} else {
 				//REMMINA_DEBUG("dt was null");
@@ -1085,8 +1111,13 @@ remmina_file_touch(RemminaFile *remminafile)
 		if (errno != ENOENT)
 			REMMINA_DEBUG("stat %s:", remminafile->statefile);
 	} else if (!r) {
+#ifdef __APPLE__
+		times[0] = st.st_atimespec;
+		times[1] = st.st_mtimespec;
+#else
 		times[0] = st.st_atim;
 		times[1] = st.st_mtim;
+#endif
 		if (utimensat(AT_FDCWD, remminafile->statefile, times, 0) < 0)
 			REMMINA_DEBUG("utimensat %s:", remminafile->statefile);
 		return;
