@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2010 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2022 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2023 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -131,7 +131,7 @@ void remmina_log_start(void)
 		gtk_header_bar_set_has_subtitle (GTK_HEADER_BAR (header), FALSE);
 		/* Stats */
 		GtkWidget *getstat = gtk_button_new ();
-		gtk_widget_set_tooltip_text (getstat, _("Paste sytem info in the Remmina debugging window"));
+		gtk_widget_set_tooltip_text (getstat, _("Paste system info in the Remmina debugging window"));
 		GIcon *icon = g_themed_icon_new ("edit-paste-symbolic");
 		GtkWidget *image = gtk_image_new_from_gicon (icon, GTK_ICON_SIZE_BUTTON);
 		g_object_unref (icon);
