@@ -1,6 +1,6 @@
 /*
  * Remmina - The GTK+ Remote Desktop Client
- * Copyright (C) 2016-2022 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2023 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -496,26 +496,4 @@ DONE:
 		fclose(file);
 
 	return digest;
-}
-
-/**
- * Generate a random sting of chars to be used as part of UID for news or stats
- * @return a string or NULL. Caller must free it with g_free().
- */
-gchar *remmina_gen_random_uuid()
-{
-	TRACE_CALL(__func__);
-	gchar *result;
-	int i;
-	static char alpha[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
-
-	result = g_malloc0(15);
-
-	for (i = 0; i < 7; i++)
-		result[i] = alpha[randombytes_uniform(sizeof(alpha))];
-
-	for (i = 0; i < 7; i++)
-		result[i + 7] = alpha[randombytes_uniform(sizeof(alpha))];
-
-	return result;
-}
+}
\ No newline at end of file
